==> mozc-2.17.2313.102.tar.xz: mozc-2.17.2313.102/src/renderer/win32/win32_font_util.h <==
// Copyright 2010-2016, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

// Windows specific font utility functions for session commands.

#ifndef MOZC_RENDERER_WIN32_WIN32_FONT_UTIL_H_
#define MOZC_RENDERER_WIN32_WIN32_FONT_UTIL_H_

#include <windows.h>

namespace mozc {
namespace commands {
class RendererCommand_WinLogFont;
}  // namespace commands

namespace win32 {

class FontUtil {
 public:
  // Serializes given LOGFONT into the WinLogFont.
  // Returns false if |win_log_font| is NULL and/or the specified LOGFONT has
  // any invalid field.
  static bool ToWinLogFont(
      const LOGFONTW &log_font,
      mozc::commands::RendererCommand_WinLogFont *win_log_font);
  // Deserializes given WinLogFont into the LOGFONT.
  // Returns false if |win_log_font| is NULL and/or the specified WinLogFont
  // has any invalid field.
  static bool ToLOGFONT(
      const mozc::commands::RendererCommand_WinLogFont &win_log_font,
      LOGFONTW *log_font);
};

}  // namespace win32
}  // namespace mozc

#endif  // MOZC_RENDERER_WIN32_WIN32_FONT_UTIL_H_

==> mozc_2.26.4220.100+dfsg.orig.tar.xz: mozc-2.26.4220.100+dfsg/src/renderer/win32/win32_font_util.h <==
// Copyright 2010-2020, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

// Windows specific font utility functions for session commands.

#ifndef MOZC_RENDERER_WIN32_WIN32_FONT_UTIL_H_
#define MOZC_RENDERER_WIN32_WIN32_FONT_UTIL_H_

#include <windows.h>

namespace mozc {
namespace commands {
class RendererCommand_WinLogFont;
}  // namespace commands

namespace win32 {

class FontUtil {
 public:
  // Serializes given LOGFONT into the WinLogFont.
  // Returns false if |win_log_font| is nullptr and/or the specified LOGFONT has
  // any invalid field.
  static bool ToWinLogFont(
      const LOGFONTW &log_font,
      mozc::commands::RendererCommand_WinLogFont *win_log_font);
  // Deserializes given WinLogFont into the LOGFONT.
  // Returns false if |win_log_font| is nullptr and/or the specified WinLogFont
  // has any invalid field.
  static bool ToLOGFONT(
      const mozc::commands::RendererCommand_WinLogFont &win_log_font,
      LOGFONTW *log_font);
};

}  // namespace win32
}  // namespace mozc

#endif  // MOZC_RENDERER_WIN32_WIN32_FONT_UTIL_H_
